%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% Investment Judgment Advisor
%%% Programed by Jhiin Joo specifically for MAC users
%%% March 3, 2009
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function varargout = Description5(varargin)
% DESCRIPTION5 M-file for Description5.fig
%      DESCRIPTION5, by itself, creates a new DESCRIPTION5 or raises the existing
%      singleton*.
%
%      H = DESCRIPTION5 returns the handle to a new DESCRIPTION5 or the handle to
%      the existing singleton*.
%
%      DESCRIPTION5('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in DESCRIPTION5.M with the given input arguments.
%
%      DESCRIPTION5('Property','Value',...) creates a new DESCRIPTION5 or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before Description1_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to Description5_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Copyright 2002-2003 The MathWorks, Inc.

% Edit the above text to modify the response to help Description5

% Last Modified by GUIDE v2.5 06-May-2009 11:32:47

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @Description5_OpeningFcn, ...
                   'gui_OutputFcn',  @Description5_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT
global ppmenu11 ppmenu12 ppmenu13 ppmenu14 ppmenu21 ppmenu22 ppmenu23 ppmenu24 
global ppmenu31 ppmenu32 ppmenu33 ppmenu34 ppmenu41 ppmenu42 ppmenu43 ppmenu44 counter
global ppmenu51 ppmenu52 ppmenu53 ppmenu54 ppmenu61 ppmenu62 ppmenu63 ppmenu64 

% --- Executes just before Description5 is made visible.
function Description5_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to Description5 (see VARARGIN)

% Choose default command line output for Description5
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes Description5 wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = Description5_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
close(Description5);
IJA_demo; %%Introduction;


% --- Executes on button press in pushbutton2.
function pushbutton2_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
close(Description5);
Description4;

% --- Executes on button press in pushbutton3.
function pushbutton3_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global ppmenu11 ppmenu12 ppmenu13 ppmenu14 ppmenu21 ppmenu22 ppmenu23 ppmenu24 
global ppmenu31 ppmenu32 ppmenu33 ppmenu34 ppmenu41 ppmenu42 ppmenu43 ppmenu44 
global ppmenu51 ppmenu52 ppmenu53 ppmenu54 ppmenu61 ppmenu62 ppmenu63 ppmenu64 
global counter templet
global popupmenu61
global ppmenu11 ppmenu12 ppmenu13 ppmenu14 ppmenu21 ppmenu22 ppmenu23 ppmenu24 
global ppmenu31 ppmenu32 ppmenu33 ppmenu34 ppmenu41 ppmenu42 ppmenu43 ppmenu44 
global ppmenu51 ppmenu52 ppmenu53 ppmenu54 ppmenu61 ppmenu62 ppmenu63 ppmenu64 
global wordsf wordss words_w MFsf MFss MFs_w
global ppmenu11string ppmenu14string ppmenu61string  WhichInv
global Xs Ws Special counter

close(Description5);
counter=0;
    ppmenu11=1; ppmenu12=1; ppmenu13=1; ppmenu14=1; 
    ppmenu21=1; ppmenu22=1; ppmenu23=1; ppmenu24=1; 
    ppmenu31=1; ppmenu32=1; ppmenu33=1; ppmenu34=1;
    ppmenu41=1; ppmenu42=1; ppmenu43=1; ppmenu44=1; 
    ppmenu51=1; ppmenu52=1; ppmenu53=1; ppmenu54=1; 
    ppmenu61=1; ppmenu62=1; ppmenu63=1; ppmenu64=1;
IJA;

